package cp_r

import (
	"git.hilo.cn/hilo-common/domain"
	"git.hilo.cn/hilo-common/mycontext"
	"github.com/gin-gonic/gin"
	"github.com/jinzhu/now"
	"hilo-user/domain/model/cp_m"
	"hilo-user/myerr/bizerr"
	"hilo-user/req"
	"hilo-user/resp"
	"time"
)

// @Tags CP v2
// @Summary 排行榜
// @Param token header string true "token"
// @Param nonce header string true "随机数字"
// @Param pageIndex query int true "偏移值 默认：1" default(1)
// @Param pageSize query int true "请求数量 默认：10" default(10)
// @Param queryType path string true "类型：day/week/month"
// @Success 200
// @Router /v2/cp/rank/{queryType} [get]
func CpRank(c *gin.Context) (*mycontext.MyContext, error) {
	myCtx := mycontext.CreateMyContext(c.Keys)
	pageReq := new(req.PageReqBase)
	if err := c.ShouldBindQuery(pageReq); err != nil {
		return myCtx, err
	}
	if pageReq.PageIndex == 0 {
		pageReq.PageIndex = 1
	}
	queryType := c.Param("queryType")
	if queryType != "day" && queryType != "week" && queryType != "month" {
		return myCtx, bizerr.InvalidParameter
	}
	var beginDate, endDate string
	switch queryType {
	case "day":
		beginDate, endDate = time.Now().Format("2006-01-02"), time.Now().Format("2006-01-02")
	case "week":
		beginDate = now.BeginningOfWeek().Format("2006-01-02")
		endDate = now.EndOfWeek().Format("2006-01-02")
	case "month":
		beginDate = now.BeginningOfMonth().Format("2006-01-02")
		endDate = now.EndOfMonth().Format("2006-01-02")
	}
	offset, limit := (pageReq.PageIndex-1)*pageReq.PageSize, pageReq.PageSize
	model := domain.CreateModelContext(myCtx)
	ranks := cp_m.PageCpDayRank(model, beginDate, endDate, offset, limit)
	resp.ResponsePageBaseOk(c, ranks, pageReq.PageIndex+1, len(ranks) < pageReq.PageSize)
	return myCtx, nil
}
